%BBOX   bounding box of an n-D binary image 
%
% SYNOPSIS:
%  [out,outb] = bbox(mask, in)
%  mask: binary mask image
%  in: optional, other image to crop to the new size
%
%  out:  the mask image cut to the bounding box
%  outb: the bounding box coordinates 
%  outg: the optional image croped to the bounding box
%
% EXAMPLE:
%  [a,b,c]=bbox(readim>210,readim)

%
% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, October 2004

function [out,outb,outg] = bbox(in,ingrey)

if nargin == 1 & ischar(in) & strcmp(in,'DIP_GetParamList') % Avoid being in menu
   out = struct('menu','none');
   return
end
if nargin>3
   error('Usage: bbox(mask,in)');
end
if ~islogical(in)
   error('Input must be binary.');
end
if nargin ==2
   if any(size(in)~=size(ingrey))
      error('Images not the same size.');
   end
end
N = ndims(in);
msr = measure(dip_image(in,'sint32'),[],{'Minimum','Maximum'});

s = 'out=in(';
ss = 'outg=ingrey(';
outb = [];
for ii=1:N
   s = [s num2str(msr.Minimum(ii)) ':' num2str(msr.Maximum(ii)) ','];
   outb = [outb; msr.Minimum(ii)  msr.Maximum(ii)];
   ss = [ss num2str(msr.Minimum(ii)) ':' num2str(msr.Maximum(ii)) ','];
end 
s(end)= [];
s = [s ');'];
eval(s);

if nargin ==2
   ss(end)= [];
   ss = [ss ');'];
   eval(ss);
end
