%CUT  cuts/crops an image symmetrical around the center 
%
% SYNOPSIS:
%  out = cut(in,newsize)
%
% PARAMETERS:
%  in:  input image
%  newsize:  new image size 
%
% EXAMPLE:
%  a=readim
%  cut(a,[300 100]) %symmetric cut
%  a(:,0:99) %cut from upper left corner 
%
% SEE ALSO:
%  extend, 

% (C) Copyright 2004           Department of Molecular Biology
%     All rights reserved      Max-Planck-Institute for Biophysical Chemistry
%                              Am Fassberg 11, 37077 G"ottingen
%                              Germany
%
% Bernd Rieger, Sep 2004.

function out = cut(varargin)
d = struct('menu','Manipulation',...
   'display','Cut (cropping)',...
   'inparams',struct('name', {'in','bor'},...
         'description',{'Input image','New image size'},...
         'type',       {'image','array'},...
         'dim_check',  {0,1},...
         'range_check',{[],'N+'},...
         'required',   {1,1},...
         'default',    {'a','256'}...
        ),...
   'outparams',struct('name',{'out'},...
                      'description',{'Output image'},...
                      'type',{'image'}...
                      )...
       );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,bor] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
if iscolor(in)
   error('Not implemented for color images.');
end
N =  ndims(in);
sz = size(in);
co = zeros(N,2);


tmp = bor > sz;
bor(tmp) = sz(tmp);%if newsize > oldsize do nothing 
if all(tmp)
   out =in;
   return;
end
co(:,1) = round((sz-bor)./2)'; %start coord
co(:,2) = round((sz+bor)./2-1)';%end coord

s = 'out=in(';
for ii=1:N
   s = [s 'co(' num2str(ii) ',1):co(' num2str(ii) ',2),'];
end
s(end) =[];
s = [s ');'];
eval(s); 
