%EX_SLICE   Extracts from an n-D image one slice
%
% SYNOPSIS:
%  out = ex_slice(in, plane, dim)
%
%  plane:  0..size(in,dim)-1   % index into image
%  dim:    0..ndims(in)-1      % dimension along which to index
%          -ndims(in)..-1      % negative dimension counts from the end
%
% DEFAULTS:
%  dim = -1; % last dimension
%
% EXAMPLE:
%  ex_slice(readim('chromo3d'),3)
%  ex_slice(readim('chromo3d'),0,0)
%  ex_slice(readim,3,1)

%
% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, September 2004
% 16 September 2004, Extended use of negative dimensions (CL)
% Feb 2005, added support for color images (BR)

function out = ex_slice(in,s,d)

if nargin == 1 & ischar(in) & strcmp(in,'DIP_GetParamList') % Avoid being in menu
   out = struct('menu','none');
   return
end
if nargin<2
   error('Usage: ex_slice(in, plane, dim)');
end
if nargin <3
   d = -1;
end
N = ndims(in{1});
if d<0
   %d = N-1;
   d = N+d;
end
if d<0 | d>N-1
   error('Dimension out of bounds.');
end
if s<0 | s>size(in{1},d+1)-1
   error('Slice out of bounds.');
end

dp = [repmat(':,',1,d),num2str(s),repmat(',:',1,N-d-1)];
if iscolor(in)
   out = newimar(ndims(in));
   for ii=1:ndims(in) %number of color channels
      ss = ['out{' num2str(ii) '} = squeeze (in{' num2str(ii)  '}(' dp '));'];
      eval(ss);   
   end
   out = colorspace(out,colorspace(in));
else
   ss = ['out = squeeze (in(' dp '));'];
   eval(ss);
end
