%EXTEND  extends/pads an image with values 
%
% SYNOPSIS:
%  out = extend(in, newsize, type, value, clip)
%
% PARAMETERS:
%  in:  input image
%  newsize:  new image size 
%  type:  'symmetric',
%         'leftup',rightup','leftlow','rightlow'
%  value: extension value 
%  clip:  clip images if newsize < oldsize 'no','yes'
%
% DEFAULTS:
%  type: 'symmetric'
%  value: 0
%  clip: 'no' (if newsize smaller than input, do nothing)
%
% EXAMPLE:
%  extend(readim,[512 512])
%  extend(readim('chromo3d'),30,'symmetric',1)
%
% SEE ALSO:
%  cut

% (C) Copyright 2004           Department of Molecular Biology
%     All rights reserved      Max-Planck-Institute for Biophysical Chemistry
%                              Am Fassberg 11, 37077 G"ottingen
%                              Germany
%
% Bernd Rieger, Sep 2004.

function out = extend(varargin)
d = struct('menu','Manipulation',...
   'display','Extend (padding)',...
   'inparams',struct('name',       {'in','bor','typ','value','clp'},...
         'description',{'Input image','New image size',...
            'Placement flavour','Value','Clipping'},...
         'type',       {'image','array','option','array','boolean'},...
         'dim_check',  {0,1,0,-1,0},...
'range_check',{[],'N+',{'symmetric','leftup','leftlow','rightup','rightlow'},'R',[]},...
         'required',   {1,1,0,0,0},...
         'default',    {'a','256','symmetric',0,0}...
        ),...
   'outparams',struct('name',{'out'},...
                      'description',{'Output image'},...
                      'type',{'image'}...
                      )...
  );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,bor,typ,value,clp] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
if iscolor(in)
   error('Not implemented for color images.');
end
in = squeeze(in);
sz=size(in);
tmp = sz>bor;
bortmp = bor;
if all(tmp)
   if clp
      out = cut(in,bor);
   else
      out=in;%nothing to do
   end
   return;
end
bor(tmp) = sz(tmp); % all extension to smaller size are put to size;
out = newim(bor,datatype(in));
if value
   out = out + value;
end

N = ndims(in);
co = zeros(N,2);
switch typ
   case 'symmetric'
      co(:,1) = floor((bor - sz)./2)'; %start coord
      co(:,2) = co(:,1)+sz'-1;         %end coord
   case 'leftup'
      co(:,1) = 0;
      co(:,2) = sz'-1;
   case 'leftlow'
      if N>2
         error('leftlow option only up to 2D');
      end
      co(1,1) = 0;
      co(2,1) = bor(2)-sz(2);  
      co(1,2) = sz(1)-1;
      co(2,2) = bor(2)-1; 
   case 'rightup'
       if N>2
         error('rightup option only up to 2D');
      end
      co(1,1) = bor(1)-sz(1);
      co(2,1) = 0;  
      co(1,2) = bor(1)-1;
      co(2,2) = sz(2)-1; 
   case 'rightlow'
      co(:,1) = bor' - sz';
      co(:,2) = bor' - 1;
   otherwise
      error('Should not happen');
end
s = 'out(';
for ii=1:N
   s = [s 'co(' num2str(ii) ',1):co(' num2str(ii) ',2),'];
end
s(end) =[];
s = [s ')=in;'];
eval(s); 
%out(co(1,1):co(1,2), co(2,1):co(2,2))=in;

%if any dimesion is smaller than the old size and clp is yes
if any(tmp) & clp
   sz2 = bor;
   sz2(tmp) = bortmp(tmp);
   out = cut(out,sz2);
end






