%RESAMPLE   Resample an image
%
% SYNOPSIS:
%  image_out = resample(image_in, zoom, translation, interpolation_method)
%
% PARAMETERS:
%  zoom        = array containing a zoom
%  translation = array containing a shift
%  interpolation_method = 'bspline', '4-cubic', '3-cubic', 'linear', 'zoh'
%
% DEFAULTS:
%  zoom        = 2
%  translation = 0
%  interpolation_method = 'linear'

% (C) Copyright 1999-2005               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, March 2001.
% ?? Changed default interpolation to linear
% 14 March 2005: Fixed zoom==0 problem.

function out = resample(varargin)

d = struct('menu','Manipulation',...
           'display','Resample',...
           'inparams',struct('name',       {'in','zoom','trans','interp'},...
                             'description',{'Input image','Zoom','Translation','Interpolation method'},...
                             'type',       {'image','array','array','option'},...
                             'dim_check',  {0,1,1,0},...
                             'range_check',{[],[realmin,+Inf],'R',{'linear','4-cubic','3-cubic','bspline','zoh'}},...
                             'required',   {1,0,0,0},...
                             'default',    {'a',2,0,'linear'}...
                            ),...
           'outparams',struct('name',{'out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
if nargin >= 4 & isequal(varargin{4},'bilinear')
   varargin{4} = 'linear';
end
try
   [in,zoom,trans,interp] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
out = dip_resampling(in,zoom,trans,interp);
