%WRITEIM_ASPECT   Write grey-value or color image to ICS file with aspect ratio
%
% SYNOPSIS:
%  writeim_aspect(image_in,filename,aspect,compression)
%
% PARAMETERS:
%  image_in:    image to write to file.
%  filename:    string with name of file, optionally with path and extension.
%  aspect:      array with as many elements as dimensions in image_in, indicating
%               the actual pixel size, or scalar value giving the aspect ratio
%               of the last dimension with respect to the rest: [1,1,aspect].
%  compression: 1 or 'yes' to use comression or 0 or 'no' not to.
%
% DEFAULTS:
%  aspect = 1
%  compression = 'yes'

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, January 2005, based on WRITEIM.
% 3 February 2005, 'aspect' paramter didn't work with image arrays.

function out = writeim_aspect(varargin)

d = struct('menu','File I/O',...
   'display','Write image w/aspect',...
   'inparams',struct('name',{'image_in','filename','aspect','compression'},...
      'description',{'Image to write','Name of the file to write','Aspect ratio','Use compression?'},...
      'type',       {'image','outfile','array','boolean'},...
      'dim_check',  {0,      0,         -1,       0},...
      'range_check',{[],     '*.*',     'R+',    []},...
      'required',   {1,      1,         0,       0},...
      'default',    {'a',    '',        1,       1}...
      )...
   );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end

%%%
if nargin>=3 & isnumeric(varargin{3}) & length(varargin{3})==1
   d.inparams(3).dim_check = 0;
end
%%%

try
   [image_in,filename,aspect,compression] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

photometric = 'gray';
N = ndims(image_in{1});
if length(aspect)~=N
   aspect = [ones(1,N-1),aspect];
end
physDims.dimensions = aspect;
if isa(image_in,'dip_image_array')
   if iscolor(image_in)
      photometric = colorspace(image_in);
      image_in = array2im(image_in);
   else
      error('Input is an image array.')
   end
end
try
   dipio_imagewriteics(image_in,filename,photometric,physDims,{},0,2,compression);
catch
   error(firsterr)
end
