%dip_initialise   Initialises the DIPlib library
%   dip_initialise must be called before using any of the DIPlib
%   functions. When DIPlib is no longer needed, a call to
%   dip_exit will remove DIPlib from memory.

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, June 2000.
% 19 April 2001: The error message is more helpful now in case of
%                wrong installation.
% 30 May 2004: Renamed the private MEX-file dip__initialise to avoid
%              confusing problems with dip_initialise.m .
% 28 Feb 2005: Removed the stupid MATLAB 5.3 required message, since
%              this is actually tested for and returns an explicit
%              message in this case. (MVG)
% 28 Feb 2005: This Microsoft-style of error reporting must cease. I am
%              adding some (hopefully) more helpful information. (MVG)
% 28 Feb 2005: Inspired by Mike's additions, also adding a check for
%              the existance of dip__initialise. (CL)

function dip_initialise(mode)

v = version;
ii = find(v=='.');
if length(ii)>1
   v = v(1:ii(2)-1);
end
ii = find(v==' ');
if ~isempty(ii)
   v = v(1:ii(1)-1);
end
v = eval(v);
if v < 5.3
   error('MATLAB 5.3 (Release 11) or later required');
end

try
   dip__initialise(1);
catch
   if ~exist('dip__initialise')
      disp(' ')
      disp(['   Initialisation of DIPlib failed because of a wrong installation. ';...
            '   please read the DIPimage user manual for information on how to   ';...
            '   install this toolbox properly. You''ll find it at:                ';...
            '   http://www.qi.tnw.tudelft.nl/DIPlib/docs/dipimage_user_manual.pdf'])      
      error('Initialisation of DIPlib failed.')
   elseif ~isempty(findstr(lasterr,'This version of DIPlib has expired.'))
      disp(' ')
      disp(' ')
      disp(['   This version of DIPimage has expired. Please visit';...
            '      http://www.ph.tn.tudelft.nl/DIPlib             ';...
            '   to obtain a new version.                          '])
      disp(' ')
      disp(' ')
      error('DIPlib has expired.')
   else
      disp(' ')
      disp(['   Initialisation of DIPlib failed. The most probable cause is';...
            '   incorrect installation. Please make sure that:             ';...
            '   - DIPlib is supported on your operating system.            ']);
      dip_systemdoctor(v,mfilename('fullpath'));
      disp(['   - Please check that these files are the correct version       ';...
            '     (not newer or older to the ones provided with the toolbox). ';...
            '                                                                 ';...
            '   Please read the manual for more information on installing this';...
            '   toolbox. It can be found at:                                  ';...
            '       http://www.ph.tn.tudelft.nl/DIPlib/docs/dipimage.pdf      '])
      disp(' ')
      disp(' ')
      error('Initialisation of DIPlib failed.')
   end
end

if nargin == 1 & ischar(mode) & strcmpi(mode,'silent')
   return
end

dipInfo = dip_getlibraryinformation;
fprintf('\n%s %s (%s - %s)\n',dipInfo.name,dipInfo.version,dipInfo.date,dipInfo.type);
fprintf('    %s\n',dipInfo.description);
fprintf('    %s\n',dipInfo.copyright);
fprintf('    %s\n\n',dipInfo.contact);

days_left = dipInfo.days_left;
isdemo = days_left >= 0;

dipInfo = dipio_getlibraryinformation;
fprintf('\n%s %s (%s - %s)\n',dipInfo.name,dipInfo.version,dipInfo.date,dipInfo.type);
fprintf('    %s\n',dipInfo.description);
fprintf('    %s\n',dipInfo.copyright);
fprintf('    %s\n\n',dipInfo.contact);

if isdemo
   fprintf('\nDIPlib with time limit: %d days left.\n\n',days_left);
end
