%dip_systemdoctor   Checks the DIPimage library installation

% (C) Copyright 1999-2005               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Michael van Ginkel, February 2005.
% 28 Feb 2005 - CL - Also checking the time stamp of the libraries.

function dip_systemdoctor( version, location )

pf='     ';
% Standard Unix settings, ok for Linux and Solaris.
psp=':';
dsp='/';
libdip='libdip.so';
libdipio='libdipio.so';
libdml='libdml.so';
fnddip='';
fnddipio='';
fnddml='';
if ~strcmp(computer,'PCWIN')
   scanpaths=getenv('LD_LIBRARY_PATH');
   disp([pf(3:end),'- The files libdip.so, libdipio.so, libdml.so']);
else
   psp=';';
   dsp='\';
   libdip='libdip.dll';
   libdipio='libdipio.dll';
   libdml='libdml.dll';
   if version>=6
      scanpaths=[matlabroot,'\bin\win32'];
   else
      scanpaths=[matlabroot,'\bin\'];
   end
   envpath=getenv('PATH');
   if ~isempty(envpath)
      scanpaths=[scanpaths,';',envpath]
   end
   disp([pf(3:end),'- The files libdip.dll, libdipio.dll, libdml.dll']);
end
disp([pf,'must be present and in the correct location.']);
disp([pf,'I will attempt to locate them for reporting purposes only.']);
disp([pf,'This will not SOLVE the problem.']);
disp(' ');

% Make a cell array of the path elements...
paths={};
pathix=[find(scanpaths==psp),length(scanpaths)+1];
ix0=1;
while pathix
   ixn=pathix(1)-1;
   if ixn>=ix0
      paths(length(paths)+1)={scanpaths(ix0:ixn)};
   end
   pathix=pathix(2:end);
   ix0=ixn+2; % Skip the directory separator
end

% Now let's scan for the DIP crap
if isempty(paths)
   if ~strcmp(computer,'PCWIN')
      disp([pf,'Did not find any directories to scan for the libraries.']);
      disp([pf,'In other words, LD_LIBRARY_PATH is not set...']);
   else
      disp([pf,'Did not find any directories to scan for the libraries.']);
      disp([pf,'In other words, PATH is not set...']);
   end
else
   for ii=1:length(paths)
      disp([pf,'Scanning ',paths{ii}]);
      cfile=[paths{ii},dsp,libdip];
      if exist( cfile, 'file' )
         disp([pf,'   Found DIPlib']);
         if isempty(fnddip)
            fnddip=cfile;
         end
      end
      cfile=[paths{ii},dsp,libdipio];
      if exist( cfile, 'file' )
         disp([pf,'   Found dipIO']);
         if isempty(fnddipio)
            fnddipio=cfile;
         end
      end
      cfile=[paths{ii},dsp,libdml];
      if exist( cfile, 'file' )
         disp([pf,'   Found dmllib']);
         if isempty(fnddml)
            fnddml=cfile;
         end
      end
   end
end
disp(' ');
disp([pf,'Summary of Library locations:']);
if fnddip
   dipt = dir(fnddip); dipt = dipt.date;
   disp([pf,'   DIPlib: ',fnddip,' (',dipt,')']);
   dipt = floor(datenum(dipt));
else
   disp([pf,'   DIPlib: not found']);
   dipt = 0;
end
if fnddipio
   dipiot = dir(fnddipio); dipiot = dipiot.date;
   disp([pf,'   dipIO:  ',fnddipio,' (',dipiot,')']);
   dipiot = floor(datenum(dipiot));
else
   disp([pf,'   dipIO:  not found']);
   dipiot = 0;
end
if fnddml
   dmlt = dir(fnddml); dmlt = dmlt.date;
   disp([pf,'   dmllib: ',fnddml,' (',dmlt,')']);
   dmlt = floor(datenum(dmlt));
else
   disp([pf,'   dmllib: not found']);
   dmlt = 0;
end
initmex = which('dip__initialise','in','dip_initialise');
initt = dir(initmex); initt = initt.date;
disp([pf,'   dip__initialise: ',initmex,' (',initt,')']);
initt = floor(datenum(initt));

if (~isempty(fnddip)) & (~isempty(fnddipio)) & (~isempty(fnddml))
   disp([pf,'Despite finding all the relevant libraries,']);
   disp([pf,'DIP does not seem to work on your system.']);
   if any([dipt,dipiot,dmlt]~=initt)
      disp(' ');
      disp([pf,'Since the dates on the found libraries and the toolbox'])
      disp([pf,'functions don''t match, it is possible that the wrong'])
      disp([pf,'version of these libraries is being used. Please remove'])
      disp([pf,'the old DIPimage/DIPlib files from your system.'])
   end
   disp(' ');
   if ~strcmp(computer,'PCWIN')
      disp([pf,'Creating a temporary file to do a ldd scan. This']);
      disp([pf,'may provide you with more information or, in the']);
      disp([pf,'worst case, more information to send to us...']);
      disp(' ');
      fd=fopen('dip_tryldd','w');
      fprintf(fd,'#! /bin/sh\n\n');
      if length(paths)>0
         fprintf(fd,['LD_LIBRARY_PATH="',paths{1},'"\n']);
      end
      for ii=2:length(paths)
         fprintf(fd,['LD_LIBRARY_PATH="$LD_LIBRARY_PATH:',paths{ii},'"\n']);
      end
      fprintf(fd,'export LD_LIBRARY_PATH\n\n');
      ix=find(location==dsp);
      lddcmd=['ldd ',location(1:ix(end)),'private',dsp,...
              'dip__initialise.',mexext,'\n'];
      fprintf(fd,lddcmd);
      fclose(fd);
      system('chmod +x dip_tryldd');
      system('./dip_tryldd; exit');
      delete('dip_tryldd');
   else
      disp([pf,'Since you are stuck with a windows machine, this is the']);
      disp([pf,'most we can do for do in terms of providing a']);
      disp([pf,'diagnosis of the problem']);
   end
end

disp(' ');
